# ezcmt
An AI CLI tool to make finding commit messages easier!\
\
It requires no internet connection and is completely free with its use of specialized local AI model.
#

# How to use
```
pip install ezcmt
ezcmt download-model
ezcmt setup-model
ezcmt generate --count 5
```
(also you should have ollama installed -> https://ollama.com/)
#

# System requirements
A GPU with a minimum of 8.5gbs of vram
